==> ihaskell-0.12.0.0-74-x86_64.pkg.tar.zst: usr/share/haskell/register/ihaskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ihaskell
version:              0.12.0.0
visibility:           public
id:                   ihaskell-0.12.0.0-1IOiUB6ZOGoK3Sk1QZbXPx
key:                  ihaskell-0.12.0.0-1IOiUB6ZOGoK3Sk1QZbXPx
license:              MIT
maintainer:           andrew.gibiansky@gmail.com
author:               Andrew Gibiansky
homepage:             http://github.com/gibiansky/IHaskell
synopsis:             A Haskell backend kernel for the Jupyter project.
description:
    IHaskell is a Haskell backend kernel for the Jupyter project. This allows using Haskell via
    a console or notebook interface. Additional packages may be installed to provide richer data visualizations.

category:             Development
abi:                  18ecbc98f54347945964b0865fdb435b
exposed:              True
exposed-modules:
    IHaskell.BrokenPackages IHaskell.CSS IHaskell.Convert
    IHaskell.Convert.Args IHaskell.Convert.IpynbToLhs
    IHaskell.Convert.LhsToIpynb IHaskell.Display
    IHaskell.Eval.Completion IHaskell.Eval.Evaluate
    IHaskell.Eval.Evaluate.HTML IHaskell.Eval.Hoogle IHaskell.Eval.Info
    IHaskell.Eval.Inspect IHaskell.Eval.Lint IHaskell.Eval.ParseShell
    IHaskell.Eval.Parser IHaskell.Eval.Util IHaskell.Eval.Widgets
    IHaskell.Flags IHaskell.IPython IHaskell.IPython.Stdin
    IHaskell.Publish IHaskell.Types IHaskellPrelude Paths_ihaskell

hidden-modules:       StringUtils
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ihaskell-0.12.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ihaskell-0.12.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ihaskell-0.12.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/ihaskell
hs-libraries:         HSihaskell-0.12.0.0-1IOiUB6ZOGoK3Sk1QZbXPx
depends:
    aeson-2.1.2.1-U8Qicry0zF1f9E1tHxOto base-4.17.2.1
    base64-bytestring-1.2.1.0-KTcFt1JBtqE6XrF8UIUkhn binary-0.8.9.1
    bytestring-0.11.5.3 cmdargs-0.10.22-KMcxPO0UszDDPT8hI73uO5
    containers-0.6.7 directory-1.3.7.1 exceptions-0.10.5
    filepath-1.4.2.2 ghc-9.4.8 ghc-boot-9.4.8
    ghc-parser-0.2.7.0-KIzcyN5x3OS2vnff2gcb1T
    ghc-paths-0.1.0.12-8lmZj1VFo8V7iNy4rcXCyj
    ghc-syntax-highlighter-0.0.9.0-1E5p823sb541YeCFB7MuPa
    haskeline-0.8.2 hlint-3.5-oqpCIR7y5iDdB7rV4xbYb
    http-client-0.7.19-LmgoxlGljmmJ4yfMmVG9tj
    http-client-tls-0.3.6.4-CWf1zUvMsiN34DRbq0lWlt
    ipython-kernel-0.11.0.0-LjsBPNwB3hPKqTZiYtYeii parsec-3.1.16.1
    process-1.6.18.0 random-1.2.1.3-BS01zQf871D7daMTFQ0UbO
    shelly-1.11.0-AzH3k83h2jF6gIV5WkVZvl
    split-0.2.5-LouByQg2aGcJvOHmCntrU0 stm-2.5.1.0
    strict-0.5-GDvTRgUj7IzA7hrFoMbqtk text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unix-2.7.3
    unordered-containers-0.2.20-KWLixwBKCEK6ORqUSVo2CW
    utf8-string-1.0.2-3k9iW3aOua82FWJzfAeOkO
    vector-0.13.2.0-BnQJYTBpbJKJ2sldbPuyJj

haddock-interfaces:   /usr/share/doc/ihaskell/html/ihaskell.haddock
haddock-html:         /usr/share/doc/ihaskell/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> ihaskell-0.12.0.0-75-x86_64.pkg.tar.zst: usr/share/haskell/register/ihaskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ihaskell
version:              0.12.0.0
visibility:           public
id:                   ihaskell-0.12.0.0-LEQS0Z1d9oQKPy8CkVqPPb
key:                  ihaskell-0.12.0.0-LEQS0Z1d9oQKPy8CkVqPPb
license:              MIT
maintainer:           andrew.gibiansky@gmail.com
author:               Andrew Gibiansky
homepage:             http://github.com/gibiansky/IHaskell
synopsis:             A Haskell backend kernel for the Jupyter project.
description:
    IHaskell is a Haskell backend kernel for the Jupyter project. This allows using Haskell via
    a console or notebook interface. Additional packages may be installed to provide richer data visualizations.

category:             Development
abi:                  a57ac4e7356fc9a1c541d2c12f71a3ff
exposed:              True
exposed-modules:
    IHaskell.BrokenPackages IHaskell.CSS IHaskell.Convert
    IHaskell.Convert.Args IHaskell.Convert.IpynbToLhs
    IHaskell.Convert.LhsToIpynb IHaskell.Display
    IHaskell.Eval.Completion IHaskell.Eval.Evaluate
    IHaskell.Eval.Evaluate.HTML IHaskell.Eval.Hoogle IHaskell.Eval.Info
    IHaskell.Eval.Inspect IHaskell.Eval.Lint IHaskell.Eval.ParseShell
    IHaskell.Eval.Parser IHaskell.Eval.Util IHaskell.Eval.Widgets
    IHaskell.Flags IHaskell.IPython IHaskell.IPython.Stdin
    IHaskell.Publish IHaskell.Types IHaskellPrelude Paths_ihaskell

hidden-modules:       StringUtils
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ihaskell-0.12.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ihaskell-0.12.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ihaskell-0.12.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/ihaskell
hs-libraries:         HSihaskell-0.12.0.0-LEQS0Z1d9oQKPy8CkVqPPb
depends:
    aeson-2.1.2.1-LvJWrHbVhNW5j5NGQeCpIT base-4.17.2.1
    base64-bytestring-1.2.1.0-2WioaI2OOHv6enJjm95P5G binary-0.8.9.1
    bytestring-0.11.5.3 cmdargs-0.10.22-KMcxPO0UszDDPT8hI73uO5
    containers-0.6.7 directory-1.3.7.1 exceptions-0.10.5
    filepath-1.4.2.2 ghc-9.4.8 ghc-boot-9.4.8
    ghc-parser-0.2.7.0-KIzcyN5x3OS2vnff2gcb1T
    ghc-paths-0.1.0.12-8lmZj1VFo8V7iNy4rcXCyj
    ghc-syntax-highlighter-0.0.9.0-3NBj6x2nrWYEzY6jlNSb5e
    haskeline-0.8.2 hlint-3.5-CoV21EmnYL47b6ZBLUkn8e
    http-client-0.7.19-AatRlGUPnZy5vGSpZr81Ei
    http-client-tls-0.3.6.4-58jh7szMQK37VFPzhWvxnZ
    ipython-kernel-0.11.0.0-Cyg5KeGVjdw1KlUwze18t8 parsec-3.1.16.1
    process-1.6.18.0 random-1.2.1.3-FjAccEVuGQcK7S7DSNXHmd
    shelly-1.11.0-3TY63fcxhXkGnefqcbXjbY
    split-0.2.5-Dujwwofvw7aEFmjRmWhj9Q stm-2.5.1.0
    strict-0.5-JoMUYyNiaM53qdwe1ZN6qo text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unix-2.7.3
    unordered-containers-0.2.20-Kt9XOM1GYdv4KClqugAe9a
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    vector-0.13.2.0-7jLyylqham1Ij3AknS5IxU

haddock-interfaces:   /usr/share/doc/ihaskell/html/ihaskell.haddock
haddock-html:         /usr/share/doc/ihaskell/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
